
.. index:: glossary

Glossary
========

.. glossary::

    onnx

        See :epkg:`onnx`.

    onnxruntime

        See :epkg:`onnxruntime`.

    scikit-learn

        See :epkg:`scikit-learn`.

    sklearn-onnx

        See :epkg:`sklearn-onnx`.
